@@ -12,6 +12,7 @@ from sqlalchemy.orm import (
     DeclarativeBase,
     Mapped,
     Session,
+    declarative_mixin,
     declared_attr,
     mapped_column,
     registry,
@@ -47,21 +48,35 @@ def touch_updated_timestamp(session: Session, *_: Any) -> None:
             session.
     """
     for instance in session.dirty:
-        instance.updated = datetime.now()
+        if hasattr(instance, "updated"):
+            instance.updated = datetime.now()
 
 
-class Base(DeclarativeBase):
-    """Base for all SQLAlchemy declarative models."""
+@declarative_mixin
+class CommonColumns:
+    """Common functionality shared between all declarative models."""
 
-    registry = registry(
-        metadata=MetaData(naming_convention=convention),
-        type_annotation_map={UUID: pg.UUID, dict: pg.JSONB},
-    )
+    __abstract__ = True
+    __name__: str
 
     id: Mapped[UUID] = mapped_column(
         default=uuid4, primary_key=True, info={DTO_KEY: dto.DTOField(mark=dto.Mark.READ_ONLY)}
     )
     """Primary key column."""
+
+    # noinspection PyMethodParameters
+    @declared_attr.directive
+    def __tablename__(cls) -> str:  # pylint: disable=no-self-argument
+        """Infer table name from class name."""
+        return cls.__name__.lower()
+
+
+@declarative_mixin
+class AuditColumns:
+    """Created/Updated At Fields Mixin."""
+
+    __abstract__ = True
+
     created: Mapped[datetime] = mapped_column(
         default=datetime.now, info={DTO_KEY: dto.DTOField(mark=dto.Mark.READ_ONLY)}
     )
@@ -69,10 +84,20 @@ class Base(DeclarativeBase):
     updated: Mapped[datetime] = mapped_column(
         default=datetime.now, info={DTO_KEY: dto.DTOField(mark=dto.Mark.READ_ONLY)}
     )
-    """Date/time of instance update."""
+    """Date/time of instance last update."""
 
-    # noinspection PyMethodParameters
-    @declared_attr.directive
-    def __tablename__(cls) -> str:  # pylint: disable=no-self-argument
-        """Infer table name from class name."""
-        return cls.__name__.lower()
+
+meta = MetaData(naming_convention=convention)
+registry_ = registry(metadata=meta, type_annotation_map={UUID: pg.UUID, dict: pg.JSONB})
+
+
+class Base(CommonColumns, DeclarativeBase):
+    """Base for all SQLAlchemy declarative models."""
+
+    registry = registry_
+
+
+class AuditBase(AuditColumns, CommonColumns, DeclarativeBase):
+    """Base for declarative models with audit columns."""
+
+    registry = registry_
