@@ -12,4 +12,7 @@ config = OpenAPIConfig(
     contact=Contact(name=settings.openapi.CONTACT_NAME, email=settings.openapi.CONTACT_EMAIL),
     use_handler_docstrings=True,
 )
-"""OpenAPI config for app, see [OpenAPISettings][starlite_saqlalchemy.settings.OpenAPISettings]"""
+"""OpenAPI config for app.
+
+See [OpenAPISettings][starlite_saqlalchemy.settings.OpenAPISettings]
+"""
